@@ -1,4 +1,4 @@
-#include <catch.hpp>
+#include <catch2/catch.hpp>
 #include <panda/time.h>
 
 using namespace panda::time;
