@@ -8,10 +8,10 @@ using xs::Simple;
 using panda::string;
 using panda::string_view;
 
-static inline const Timezone* list2vals (SV** args, I32 items, ptime_t vals[8]) {
+static inline TimezoneSP list2vals (SV** args, I32 items, ptime_t vals[8]) {
     if (!items) return nullptr;
 
-    const Timezone* tz = nullptr;
+    TimezoneSP tz;
     if (SvPOK(args[0]) && !looks_like_number(args[0])) {
         for (I32 i = 0; i < items - 1; i += 2) {
             SV* keysv = args[i];
@@ -22,7 +22,7 @@ static inline const Timezone* list2vals (SV** args, I32 items, ptime_t vals[8])
                 case 'd': if (key == "day"  ) vals[2] = xs::in<ptime_t>(args[i+1]); break;
                 case 'h': if (key == "hour" ) vals[3] = xs::in<ptime_t>(args[i+1]); break;
                 case 's': if (key == "sec"  ) vals[5] = xs::in<ptime_t>(args[i+1]); break;
-                case 't': if (key == "tz"   ) tz      = xs::in<const Timezone*>(args[i+1]); break;
+                case 't': if (key == "tz"   ) tz      = xs::in<TimezoneSP>(args[i+1]); break;
                 case 'i': if (key == "isdst") vals[7] = SvIV(args[i+1]); break;
                 case 'm': switch (key[1]) {
                     case 'o': if (key == "month") vals[1] = xs::in<ptime_t>(args[i+1]); break;
@@ -36,7 +36,7 @@ static inline const Timezone* list2vals (SV** args, I32 items, ptime_t vals[8])
     } else {
         if (items > 8) items = 8;
         switch (items) {
-            case 8: tz      = xs::in<const Timezone*>(args[7]);
+            case 8: tz      = xs::in<TimezoneSP>(args[7]);
             case 7: vals[6] = SvIV(args[6]);
             case 6: vals[5] = xs::in<ptime_t>(args[5]);
             case 5: vals[4] = xs::in<ptime_t>(args[4]);
